@@ -2,10 +2,12 @@ import os
 import contextlib
 import json
 from abc import ABC, abstractmethod
+from typing import Optional
 from shared_dependencies.sentry import safe_capture_exception
 from shared_dependencies.http_client import CustomAsyncClient
 
 
+
 @contextlib.asynccontextmanager
 async def patient_httpx_client(*args, **kwargs):
     async with httpx.AsyncClient(
@@ -14,8 +16,22 @@ async def patient_httpx_client(*args, **kwargs):
         yield client
 
 
+def get_openid_config_url(http_exception, url: str, app_id: Optional[str], tenant_id: Optional[str]) -> str:
+    if tenant_id:
+        return url.replace("common", settings.internal_tenant_id)
+    elif app_id:
+        return f"{url}?appid={settings.internal_app_id}"
+    else:
+        event_id = capture_message("No valid app_id or tenant_id provided")
+        raise http_exception(
+            status_code=401,
+            detail={"message": "No valid app_id or tenant_id provided", "sentry_eventid": event_id},
+        )
+
+
 @contextlib.asynccontextmanager
-async def openid_config(url: str, http_exception, status_code: int):
+async def openid_config(base_url: str, http_exception, status_code: int):
+    url = get_openid_config_url(http_exception, url=base_url, app_id=app_id, tenant_id=tenant_id)
     try:
         res = await CustomAsyncClient().get(url)
         conf = res.json()
